from RACER import RACER, RACERPreprocessor
from sklearn.datasets import load_iris
from sklearn.model_selection import train_test_split


def test_workflow_integrity():
    X, y = load_iris(return_X_y=True)
    X, y = RACERPreprocessor().fit_transform(X, y)
    X_train, X_test, y_train, y_test = train_test_split(
        X, y, random_state=1, test_size=0.3
    )
    racer = RACER(alpha=0.95)
    racer.fit(X_train, y_train)
    acc = racer.score(X_test, y_test)
    assert acc > 0.75

def test_dominance_independence():
    X, y = load_iris(return_X_y=True)
    X, y = RACERPreprocessor().fit_transform(X, y)
    racer = RACER(alpha=0.95)
    racer.fit(X, y)
    for i in range(len(racer._final_rules_if)):
        for j in range(i+1, len(racer._final_rules_if)):
            assert not racer._covered(
                racer._final_rules_if[j], racer._final_rules_if[i]
            )


import numpy as np
from RACER import RACERPreprocessor
from sklearn.datasets import load_iris


def test_output_equiv():
    X, y = load_iris(return_X_y=True)
    X1, y1 = RACERPreprocessor().fit_transform(X, y)
    X2, y2 = RACERPreprocessor(target="multiclass").fit_transform(X, y)
    X3, y3 = RACERPreprocessor().fit_transform_pandas(X, y)
    X4, y4 = RACERPreprocessor(target="multiclass").fit_transform_pandas(X, y)
    preprocessor1 = RACERPreprocessor()
    preprocessor1.fit(X, y)
    preprocessor2 = RACERPreprocessor(target="multiclass")
    preprocessor2.fit(X, y)
    X5, y5 = preprocessor1.transform(X, y)
    X6, y6 = preprocessor2.transform(X, y)
    Xs_tfmd, ys_tfmd = [X1, X2, X3, X4, X5, X6], [y1, y2, y3, y4, y5, y6]
    for i in range(1, len(Xs_tfmd)):
        assert np.all(Xs_tfmd[i] == Xs_tfmd[i - 1])
        assert np.all(ys_tfmd[i] == ys_tfmd[i - 1])
        assert Xs_tfmd[i].shape == Xs_tfmd[i - 1].shape
        assert ys_tfmd[i].shape == ys_tfmd[i - 1].shape
